==> cloud-4.0.0-beta1.tar.gz: cloud/modules/cloud_service_providers/aws_cloud/src/Entity/Vpc/InternetGatewayInterface.php <==
<?php

namespace Drupal\aws_cloud\Entity\Vpc;

use Drupal\aws_cloud\Entity\Ec2\AwsCloudEntityInterface;
use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\user\EntityOwnerInterface;

/**
 * Provides an interface defining a Internet Gateway entity.
 *
 * @ingroup aws_cloud
 */
interface InternetGatewayInterface extends ContentEntityInterface, EntityOwnerInterface, AwsCloudEntityInterface {

  /**
   * {@inheritdoc}
   */
  public function getInternetGatewayId(): ?string;

  /**
   * {@inheritdoc}
   */
  public function setInternetGatewayId($internet_gateway_id = ''): InternetGatewayInterface;

  /**
   * {@inheritdoc}
   */
  public function getVpcId(): ?string;

  /**
   * {@inheritdoc}
   */
  public function setVpcId($vpc_id = ''): InternetGatewayInterface;

  /**
   * {@inheritdoc}
   */
  public function getAccountId(): ?string;

  /**
   * {@inheritdoc}
   */
  public function setAccountId($account_id): InternetGatewayInterface;

  /**
   * {@inheritdoc}
   */
  public function getState(): string;

  /**
   * {@inheritdoc}
   */
  public function setState($state): InternetGatewayInterface;

  /**
   * {@inheritdoc}
   */
  public function getTags(): array;

  /**
   * {@inheritdoc}
   */
  public function setTags(array $tags): InternetGatewayInterface;

  /**
   * {@inheritdoc}
   */
  public function getRefreshed(): string;

  /**
   * {@inheritdoc}
   */
  public function setRefreshed($time): InternetGatewayInterface;

  /**
   * {@inheritdoc}
   */
  public function setCreated($created = 0): InternetGatewayInterface;

  /**
   * {@inheritdoc}
   */
  public function created();

  /**
   * {@inheritdoc}
   */
  public function changed();

}

==> cloud-5.0.0-beta1.tar.gz: cloud/modules/cloud_service_providers/aws_cloud/src/Entity/Vpc/InternetGatewayInterface.php <==
<?php

namespace Drupal\aws_cloud\Entity\Vpc;

use Drupal\aws_cloud\Entity\Ec2\AwsCloudEntityInterface;
use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\user\EntityOwnerInterface;

/**
 * Provides an interface defining an internet gateway entity.
 *
 * @ingroup aws_cloud
 */
interface InternetGatewayInterface extends ContentEntityInterface, EntityOwnerInterface, AwsCloudEntityInterface {

  /**
   * {@inheritdoc}
   */
  public function getInternetGatewayId(): ?string;

  /**
   * {@inheritdoc}
   */
  public function setInternetGatewayId($internet_gateway_id = ''): InternetGatewayInterface;

  /**
   * {@inheritdoc}
   */
  public function getVpcId(): ?string;

  /**
   * {@inheritdoc}
   */
  public function setVpcId($vpc_id = ''): InternetGatewayInterface;

  /**
   * {@inheritdoc}
   */
  public function getAccountId(): ?string;

  /**
   * {@inheritdoc}
   */
  public function setAccountId($account_id): InternetGatewayInterface;

  /**
   * {@inheritdoc}
   */
  public function getState(): string;

  /**
   * {@inheritdoc}
   */
  public function setState($state): InternetGatewayInterface;

  /**
   * {@inheritdoc}
   */
  public function getTags(): array;

  /**
   * {@inheritdoc}
   */
  public function setTags(array $tags): InternetGatewayInterface;

  /**
   * {@inheritdoc}
   */
  public function getRefreshed(): string;

  /**
   * {@inheritdoc}
   */
  public function setRefreshed($time): InternetGatewayInterface;

  /**
   * {@inheritdoc}
   */
  public function setCreated($created = 0): InternetGatewayInterface;

  /**
   * {@inheritdoc}
   */
  public function created();

  /**
   * {@inheritdoc}
   */
  public function changed();

}
